@import url("nature.css");

body {
    background-color:white;
}

div.sphinxsidebar {
    background-color:#f2f2f2;
}

div.sphinxsidebarwrapper {
    padding-top:0px;
}

div.sphinxsidebar h3, div.sphinxsidebar h4 {
    background-color:#d0d8e5;
}

div.footer {
    color:#000000;
}

div.related {
    background-color:#ccd9e6;
}

div.related, div.related a {
    color:#222222;
    text-shadow:1px 1px 0 white;
}

div.body h1,
div.body h2,
div.body h3,
div.body h4,
div.body h5,
div.body h6 {
    background-color:transparent;
    text-shadow:1px 1px 0 #cccccc;
}

div.body dt {
    border:1px solid #cccccc;
    border-right:none;
    border-bottom:none;
    padding-top:3px;
    padding-left:3px;
}

div.body dd dt {
    border:none;
    padding:none;
}

a {
    color:#8c9fbf;
}